==> affydata_1.11.5.zip: affydata/doc/affydata.R <==
###################################################
### chunk number 1: 
###################################################
library(affydata)
data(Dilution)


###################################################
### chunk number 2: 
###################################################
Dilution


###################################################
### chunk number 3: 
###################################################
phenoData(Dilution)
pData(Dilution)


###################################################
### chunk number 4: 
###################################################
pData(Dilution) ##notice the scanner covariate


###################################################
### chunk number 5: 
###################################################
par(mfrow=c(1,1))
boxplot(Dilution,col=c(2,2,3,3))


###################################################
### chunk number 6: 
###################################################
options(warn=-1)


###################################################
### chunk number 7: 
###################################################
gn <- sample(geneNames(Dilution),100) ##pick only a few genes
pms <- pm(Dilution[3:4],gn)
mva.pairs(pms)


###################################################
### chunk number 8: 
###################################################
normalized.Dilution <- merge(normalize(Dilution[1:2]),
                             normalize(Dilution[3:4]))


###################################################
### chunk number 9: 
###################################################
normalize.methods(Dilution)


###################################################
### chunk number 10: 
###################################################
boxplot(normalized.Dilution,col=c(2,2,3,3))


###################################################
### chunk number 11: 
###################################################
pms <- pm(normalized.Dilution[3:4],gn)
mva.pairs(pms)

==> affydata_1.11.10.zip: affydata/doc/affydata.R <==
###################################################
### chunk number 1: 
###################################################
library(affydata)
data(Dilution)


###################################################
### chunk number 2: 
###################################################
Dilution


###################################################
### chunk number 3: 
###################################################
phenoData(Dilution)
pData(Dilution)


###################################################
### chunk number 4: 
###################################################
pData(Dilution) ##notice the scanner covariate


###################################################
### chunk number 5: 
###################################################
par(mfrow=c(1,1))
boxplot(Dilution,col=c(2,2,3,3))


###################################################
### chunk number 6: 
###################################################
options(warn=-1)


###################################################
### chunk number 7: 
###################################################
gn <- sample(geneNames(Dilution),100) ##pick only a few genes
pms <- pm(Dilution[,3:4], gn)
mva.pairs(pms)


###################################################
### chunk number 8: 
###################################################
normalized.Dilution <- Biobase::combine(normalize(Dilution[, 1:2]),
                             normalize(Dilution[, 3:4]))


###################################################
### chunk number 9: 
###################################################
normalize.methods(Dilution)


###################################################
### chunk number 10: 
###################################################
boxplot(normalized.Dilution, col=c(2,2,3,3), main="Normalized Arrays")


###################################################
### chunk number 11: 
###################################################
pms <- pm(normalized.Dilution[, 3:4],gn)
mva.pairs(pms)
